[![pipeline status](https://vcs.basement.technology/basement/django-generic-rest/badges/master/pipeline.svg)](https://vcs.basement.technology/basement/django-generic-rest/commits/master) [![coverage report](https://vcs.basement.technology/basement/django-generic-rest/badges/master/coverage.svg)](https://vcs.basement.technology/basement/django-generic-rest/commits/master)

# django-generic-rest
Provides reusable REST API view components.

## Packaging
```
python setup.py sdist
```

## Running tests
```
coverage run ./runtests.py --noinput
coverage report
```